@@ -192,7 +192,7 @@ def addhubuser(hubname, username, fname, mname, lname, email, pw, pwdisabled, jo
 	db =  hubzero.data.db.mySql("localhost", dbName, dbUserName, dbPW)
 
 	if _userExists(db, username):
-		print "User already exists" + username
+		print "User already exists: " + username
 		return (-1)
 	
 	fullname = fname + ' ' + lname
@@ -215,7 +215,7 @@ def addhubuser(hubname, username, fname, mname, lname, email, pw, pwdisabled, jo
 		print procStdOut
 		if rc:
 			print procStdErr
-		gidNumber = _insert_jos_xgroups(db, name, description)	
+		gidNumber = hubzero.utilities.group._insert_jos_xgroups(db, name, description)	
 		hubzero.utilities.group._insert_jos_xgroups_members(gidNumber, userID)
 		
 
